@@ -1,8 +1,7 @@
 package UUID;
-
 require 5.005;
 use strict;
-#use warnings;
+use warnings;
 
 require Exporter;
 require DynaLoader;
@@ -10,6 +9,8 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(Exporter DynaLoader);
 
+$VERSION = '0.30_02';
+
 # This allows declaration       use UUID ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
@@ -23,8 +24,6 @@ use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 
 @EXPORT_OK = ( @{$EXPORT_TAGS{'all'}} );
 
-$VERSION = '0.30_01';
-
 bootstrap UUID $VERSION;
 
 # Preloaded methods go here.
